@@ -1,28 +1,56 @@
 package App::Dest;
 # ABSTRACT: Deployment State Manager
 
+use 5.016_003;
 use strict;
 use warnings;
-use 5.016;
 
-use Cwd 'getcwd';
 use File::Basename qw( dirname basename );
+use File::Copy 'copy';
 use File::Copy::Recursive 'dircopy';
 use File::DirCompare ();
 use File::Find 'find';
 use File::Path qw( mkpath rmtree );
 use IPC::Run 'run';
+use Path::Tiny 'path';
 use Text::Diff ();
-use Try::Tiny qw( try catch );
+use Try::Tiny qw( try catch finally );
 
-our $VERSION = '1.14'; # VERSION
+our $VERSION = '1.15'; # VERSION
 
-my %seen_files;
+my $env;
+
+sub clear {
+    $env = undef;
+    return __PACKAGE__;
+}
+
+sub _env {
+    return $env->{root_dir} if $env and $env->{root_dir};
+
+    $env = {
+        cwd        => Path::Tiny->cwd,
+        dir_depth  => 0,
+        seen_files => {},
+    };
+    $env->{root_dir} = $env->{cwd};
+
+    while ( not $env->{root_dir}->child('.dest')->is_dir ) {
+        if ( $env->{root_dir}->is_rootdir ) {
+            $env->{root_dir} = '';
+            last;
+        }
+        $env->{root_dir} = $env->{root_dir}->parent;
+        $env->{dir_depth}++;
+    }
+
+    return $env->{root_dir};
+}
 
 sub init {
     my ($self) = @_;
+    die "Project already initialized\n" if _env();
 
-    die "Project already initialized\n" if ( -d '.dest' );
     mkdir('.dest') or die "Unable to create .dest directory\n";
     open( my $watch, '>', '.dest/watch' ) or die "Unable to create .dest/watch file\n";
 
@@ -50,58 +78,124 @@ sub init {
                     : ''
             );
     }
+
+    clear();
+    _env();
     return 0;
 }
 
 sub add {
-    my ( $self, $dir ) = @_;
-    $dir //= '';
-    $dir =~ s|/$||;
+    my $self = shift;
+    die "Project not initialized\n" unless _env();
+    die "No directory specified; usage: dest add [directory]\n" unless ( $_[0] );
 
-    _find_root_dir();
-    die "No directory specified; usage: dest add [directory]\n" unless ($dir);
-    die "Directory specified does not exist\n" unless ( -d $dir );
-    die "Directory $dir already added\n" if ( grep { $dir eq $_ } $self->_watches );
+    my @watches = $self->watch_list;
+    my @adds    = map {
+        my $dir = $_;
+        die "Directory specified does not exist\n" unless ( -d $dir );
 
-    open( my $watch, '>>', '.dest/watch' ) or die "Unable to write .dest/watch file\n";
-    print $watch $dir, "\n";
+        my $rel_dir = _rel2root($dir);
+        die "Directory $dir already added\n" if ( grep { $rel_dir eq $_ } @watches );
+        $rel_dir;
+    } @_;
 
-    mkpath(".dest/$dir");
+    open( my $watch, '>', _rel2dir('.dest/watch') ) or die "Unable to write .dest/watch file\n";
+    print $watch $_, "\n" for ( sort @adds, map { _rel2root($_) } @watches );
+    mkpath("$env->{root_dir}/.dest/$_") for (@adds);
     return 0;
 }
 
 sub rm {
-    my ( $self, $dir ) = @_;
-    $dir //= '';
-    $dir =~ s|/$||;
+    my $self = shift;
+    die "Project not initialized\n" unless _env();
+    die "No directory specified; usage: dest rm [directory]\n" unless ( $_[0] );
 
-    die "Not in project root directory or project not initialized\n" unless ( -d '.dest' );
-    die "No directory specified; usage: dest rm [directory]\n" unless ($dir);
-    die "Directory $dir not currently tracked\n" unless ( grep { $dir eq $_ } $self->_watches );
+    my @watches = $self->watch_list;
+    my @rms     = map {
+        my $dir = $_;
+        $dir //= '';
+        $dir =~ s|/$||;
 
-    my @watches = $self->_watches;
-    open( my $watch, '>', '.dest/watch' ) or die "Unable to write .dest/watch file\n";
-    print $watch $_, "\n" for ( grep { $_ ne $dir } @watches );
+        die "Directory $dir not currently tracked\n" unless ( grep { $dir eq $_ } @watches );
 
-    rmtree(".dest/$dir");
+        _rel2root($dir);
+    } @_;
+
+    open( my $watch_file, '>', _rel2dir('.dest/watch') ) or die "Unable to write .dest/watch file\n";
+    for my $watch_dir ( map { _rel2root($_) } @watches ) {
+        if ( grep { $watch_dir eq $_ } @rms ) {
+            rmtree( _rel2dir(".dest/$watch_dir") );
+        }
+        else {
+            print $watch_file $watch_dir, "\n";
+        }
+    }
+
+    return 0;
+}
+
+sub watch_list {
+    _env();
+    open( my $watch, '<', _rel2dir('.dest/watch') ) or die "Unable to read ~/.dest/watch file\n";
+    return sort { $a cmp $b } map { chomp; _rel2dir($_) } <$watch>;
+}
+
+sub watches {
+    my ($self) = @_;
+    die "Project not initialized\n" unless _env();
+
+    my @watches = $self->watch_list;
+    print join( "\n", @watches ), "\n" if @watches;
+    return 0;
+}
+
+sub putwatch {
+    my ( $self, $file ) = @_;
+    die "Project not initialized\n" unless _env();
+    die "File specified does not exist\n" unless ( -f $file );
+
+    open( my $new_watches, '<', $file ) or die "Unable to read specified file\n";
+
+    my @new = map { chomp; $_ } <$new_watches>;
+    my @old = $self->watch_list;
+
+    for my $old (@old) {
+        next if ( grep { $_ eq $old } @new );
+        $self->rm($old);
+    }
+    for my $new (@new) {
+        next if ( grep { $_ eq $new } @old );
+        $self->add($new);
+    }
+
+    return 0;
+}
+
+sub writewatch {
+    my ($self) = @_;
+    _env();
+    copy( _rel2dir('.dest/watch'), _rel2dir('dest.watch') ) or die "$!\n";
     return 0;
 }
 
 sub make {
     my ( $self, $path, $ext ) = @_;
+    die "Project not initialized\n" unless _env();
     die "No name specified; usage: dest make [path]\n" unless ($path);
 
     $ext = '.' . $ext if ( defined $ext );
     $ext //= '';
 
-    eval {
+    try {
         mkpath($path);
         for ( qw( deploy verify revert ) ) {
             open( my $file, '>', "$path/$_$ext" ) or die;
             print $file "\n";
         }
+    }
+    catch {
+        die "Failed to fully make $path; check permissions or existing files\n";
     };
-    die "Failed to fully make $path; check permissions or existing files\n" if ($@);
 
     $self->list($path);
     return 0;
@@ -109,12 +203,13 @@ sub make {
 
 sub list {
     my ( $self, $path ) = @_;
+    die "Project not initialized\n" unless _env();
 
     if ($path) {
         print join( ' ', map { <"$path/$_*"> } qw( deploy verify revert ) ), "\n";
     }
     else {
-        for my $path ( $self->_watches ) {
+        for my $path ( $self->watch_list ) {
             print $path, "\n";
 
             find( {
@@ -134,43 +229,44 @@ sub list {
 
 sub status {
     my ($self) = @_;
-    _find_root_dir();
+    die "Project not initialized\n" unless _env();
 
-    if ( -f 'dest.watch' ) {
-        my $diff = Text::Diff::diff( '.dest/watch', 'dest.watch' );
-        warn "Diff between current watch list and dest.watch file:\n" . $diff if ($diff);
+    if ( -f _rel2dir('dest.watch') ) {
+        my $diff = Text::Diff::diff( _rel2dir('.dest/watch'), _rel2dir('dest.watch') );
+        warn "Diff between current watch list and dest.watch file:\n" . $diff . "\n" if ($diff);
     }
 
     my %seen_actions;
-    for ( $self->_watches ) {
+    for ( $self->watch_list ) {
         my ( $this_path, $printed_path ) = ( $_, 0 );
 
-        eval { File::DirCompare->compare( ".dest/$_", $_, sub {
-            my ( $a, $b ) = @_;
-            return if ( $a and $a =~ /\/dest.wrap$/ or $b and $b =~ /\/dest.wrap$/ );
-            print 'diff - ', $this_path, "\n" unless ( $printed_path++ );
+        try {
+            File::DirCompare->compare( _rel2dir( '.dest/' . _rel2root($this_path) ), $this_path, sub {
+                my ( $a, $b ) = @_;
+                return if ( $a and $a =~ /\/dest.wrap$/ or $b and $b =~ /\/dest.wrap$/ );
+                print 'diff - ', $this_path, "\n" unless ( $printed_path++ );
 
-            if ( not $b ) {
-                print '  - ', substr( $a, 7 ), "\n";
-            }
-            elsif ( not $a ) {
-                print "  + $b\n";
-            }
-            else {
-                ( my $action = $b ) =~ s,/(?:deploy|verify|revert)$,,;
-                print "  $action\n" unless ( $seen_actions{$action}++ );
-                print "    M $b\n";
-            }
+                if ( not $b ) {
+                    print '  - ', substr( $a, 7 ), "\n";
+                }
+                elsif ( not $a ) {
+                    print "  + $b\n";
+                }
+                else {
+                    ( my $action = $b ) =~ s,/(?:deploy|verify|revert)$,,;
+                    print "  $action\n" unless ( $seen_actions{$action}++ );
+                    print "    M $b\n";
+                }
 
-            return;
-        } ) };
-
-        if ( $@ and $@ =~ /Not a directory/ ) {
-            print '? - ', $this_path, "\n";
+                return;
+            } )
         }
-        else {
-            print 'ok - ', $this_path, "\n" unless ($printed_path);
+        catch {
+            print '? - ', $this_path, "\n" if ( /Not a directory/ );
         }
+        finally {
+            print 'ok - ', $this_path, "\n" unless ( /Not a directory/ or $printed_path );
+        };
     }
 
     return 0;
@@ -178,34 +274,108 @@ sub status {
 
 sub diff {
     my ( $self, $path ) = @_;
+    die "Project not initialized\n" unless _env();
 
     if ( not defined $path ) {
-        $self->diff($_) for ( $self->_watches );
+        $self->diff($_) for ( $self->watch_list );
         return 0;
     }
 
-    eval { File::DirCompare->compare( ".dest/$path", $path, sub {
-        my ( $a, $b ) = @_;
-        $a ||= '';
-        $b ||= '';
+    try {
+        File::DirCompare->compare( _rel2dir( '.dest/' . _rel2root($path) ), $path, sub {
+            my ( $a, $b ) = @_;
+            $a ||= '';
+            $b ||= '';
 
-        return if ( $a =~ /\/dest.wrap$/ or $b =~ /\/dest.wrap$/ );
-        print Text::Diff::diff( $a, $b );
-        return;
-    } ) };
+            return if ( $a =~ /\/dest.wrap$/ or $b =~ /\/dest.wrap$/ );
+            print Text::Diff::diff( $a, $b );
+            return;
+        } )
+    };
 
     return 0;
 }
 
+sub clean {
+    my ($self) = @_;
+    die "Project not initialized\n" unless _env();
+
+    for ( map { _rel2root($_) } $self->watch_list ) {
+        my $dest = _rel2dir(".dest/$_");
+        rmtree($dest);
+        dircopy( _rel2dir($_), $dest );
+    }
+    return 0;
+}
+
+sub preinstall {
+    my ($self) = @_;
+    die "Project not initialized\n" unless _env();
+
+    for ( map { _rel2root($_) } $self->watch_list ) {
+        my $dest = _rel2dir(".dest/$_");
+        rmtree($dest);
+        mkdir($dest);
+    }
+    return 0;
+}
+
+sub deploy {
+    my ( $self, $name, $redeploy ) = @_;
+    die "Project not initialized\n" unless _env();
+    die "File to deploy required; usage: dest deploy file\n" unless ($name);
+
+    my $rv = $self->_action( $name, 'deploy', $redeploy );
+    dircopy( $_, _rel2dir( '.dest/' . _rel2root($_) ) )
+        for ( grep { s|/deploy[^/]*$|| } keys %{ $env->{seen_files} } );
+
+    return $rv;
+}
+
+sub verify {
+    my ( $self, $path ) = @_;
+    die "Project not initialized\n" unless _env();
+
+    return $self->_action( $path, 'verify' );
+}
+
+sub revert {
+    my ( $self, $name ) = @_;
+    die "Project not initialized\n" unless _env();
+    die "File to revert required; usage: dest revert file\n" unless ($name);
+
+    my $rv = $self->_action( _rel2dir( '.dest/' . _rel2root($name) ), 'revert' );
+    rmtree( _rel2dir( _rel2root($_) ) ) for (
+        grep { s|/revert[^/]*$|| } keys %{ $env->{seen_files} }
+    );
+
+    return $rv;
+}
+
+sub redeploy {
+    my ( $self, $name ) = @_;
+    die "Project not initialized\n" unless _env();
+
+    return $self->deploy( $name, 'redeploy' );
+}
+
+sub revdeploy {
+    my ( $self, $name ) = @_;
+    die "Project not initialized\n" unless _env();
+
+    $self->revert($name);
+    return $self->deploy($name);
+}
+
 sub update {
     my $self = shift;
-    _find_root_dir();
+    die "Project not initialized\n" unless _env();
 
-    if ( -f 'dest.watch' ) {
-        my @watches = $self->_watches;
-        open( my $watch, '<', 'dest.watch' ) or die "Unable to read dest.watch file\n";
+    if ( -f _rel2dir('dest.watch') ) {
+        my @watches = $self->watch_list;
+        open( my $watch, '<', _rel2dir('dest.watch') ) or die "Unable to read dest.watch file\n";
 
-        for my $candidate ( map { chomp; $_ } <$watch> ) {
+        for my $candidate ( map { chomp; _rel2dir($_) } <$watch> ) {
             unless ( grep { $_ eq $candidate } @watches ) {
                 $self->add($candidate);
                 warn "Added $candidate to the watch list\n";
@@ -214,7 +384,7 @@ sub update {
     }
 
     my @paths   = @_;
-    my @watches = $self->_watches;
+    my @watches = $self->watch_list;
 
     if (@paths) {
         @watches = grep {
@@ -223,7 +393,7 @@ sub update {
         } @watches;
     }
 
-    File::DirCompare->compare( ".dest/$_", $_, sub {
+    File::DirCompare->compare( _rel2dir( '.dest/' . _rel2root($_) ), $_, sub {
         my ( $a, $b ) = @_;
         return if ( $a and $a =~ /\/dest.wrap$/ or $b and $b =~ /\/dest.wrap$/ );
 
@@ -246,7 +416,7 @@ sub update {
                 $self->deploy($b);
             }
             else {
-                $self->dircopy( $a, ".dest/$a" );
+                dircopy( $a, _rel2dir( '.dest' . _rel2root($a) ) );
             }
         }
     } ) for (@watches);
@@ -254,83 +424,9 @@ sub update {
     return 0;
 }
 
-sub verify {
-    my ( $self, $path ) = @_;
-    _find_root_dir();
-    return $self->_action( $path, 'verify' );
-}
-
-sub deploy {
-    my ( $self, $name, $redeploy ) = @_;
-    die "File to deploy required; usage: dest deploy file\n" unless ($name);
-    _find_root_dir();
-    my $rv = $self->_action( $name, 'deploy', $redeploy );
-    dircopy( $_, ".dest/$_" ) for ( grep { s|/deploy[^/]*$|| } keys %seen_files );
-    return $rv;
-}
-
-sub revert {
-    my ( $self, $name ) = @_;
-    die "File to revert required; usage: dest revert file\n" unless ($name);
-    _find_root_dir();
-    my $rv = $self->_action( ".dest/$name", 'revert' );
-    rmtree(".dest/$_") for ( map { s|^.dest/||; $_ } grep { s|/revert[^/]*$|| } keys %seen_files );
-    return $rv;
-}
-
-sub redeploy {
-    my ( $self, $name ) = @_;
-    return $self->deploy( $name, 'redeploy' );
-}
-
-sub revdeploy {
-    my ( $self, $name ) = @_;
-    $self->revert($name);
-    return $self->deploy($name);
-}
-
-sub clean {
-    my ($self) = @_;
-    _find_root_dir();
-    for ( $self->_watches ) {
-        rmtree(".dest/$_");
-        dircopy( $_, ".dest/$_" );
-    }
-    return 0;
-}
-
-sub preinstall {
-    my ($self) = @_;
-    _find_root_dir();
-    for ( $self->_watches ) {
-        rmtree(".dest/$_");
-        mkdir(".dest/$_");
-    }
-    return 0;
-}
-
-sub watches {
-    my ($self) = @_;
-    print join( "\n", $self->_watches ), "\n";
-    return 0;
-}
-
-sub _find_root_dir {
-    while ( getcwd() ne '/' ) {
-        return if ( -d '.dest' );
-        chdir('..');
-    }
-    die "Failed to find project root dir; run init in project root dir to resolve\n";
-}
-
-sub _watches {
-    open( my $watch, '<', '.dest/watch' ) or die "Unable to read .dest/watch file\n";
-    return sort { $a cmp $b } map { chomp; $_ } <$watch>;
-}
-
 sub _action {
     my ( $self, $path, $type, $redeploy ) = @_;
-    %seen_files = ();
+    $env->{seen_files} = {};
 
     if ($path) {
         my @files = <"$path/$type*">;
@@ -338,9 +434,10 @@ sub _action {
 
         unless ($file) {
             my $this_file = ( split( '/', $path ) )[-1];
-            die "Unable to $type $this_file (perhaps action has already occured)\n";
+            die "Unable to $type $this_file "
+                . "(perhaps $this_file $type has already occured or $this_file isn't an action)\n";
         }
-        $self->_execute( $file, $redeploy ) or die "Failed to $type $path\n";
+        $self->_execute( $file, $redeploy ) or die "Failed to $type $path (check interdependencies)\n";
     }
     else {
         find( {
@@ -350,7 +447,7 @@ sub _action {
                 return unless ( /\/$type/ );
                 $self->_execute($_) or die "Failed to $type $_\n";
             },
-        }, $self->_watches );
+        }, $self->watch_list );
     }
 
     return 0;
@@ -358,16 +455,17 @@ sub _action {
 
 sub _execute {
     my ( $self, $file, $run_quiet, $is_dependency ) = @_;
-    return if ( $seen_files{$file}++ );
+    return if ( $env->{seen_files}{$file}++ );
+
+    my @nodes = split( '/', _rel2root($file) );
 
-    my @nodes = split( '/', $file );
     my $type = pop @nodes;
-    ( my $action = join( '/', @nodes ) ) =~ s|^\.dest/||;
-
     $type =~ s/\..*$//;
 
+    ( my $action = join( '/', @nodes ) ) =~ s|(?<!\w)\.dest/||;
+
     if (
-        ( $type eq 'deploy' and not $run_quiet and -f '.dest/' . $file ) or
+        ( $type eq 'deploy' and not $run_quiet and -f _rel2dir( '.dest/' . _rel2root($file) ) ) or
         ( $type eq 'revert' and not -f $file )
     ) {
         if ( $is_dependency ) {
@@ -385,37 +483,59 @@ sub _execute {
         map { /dest\.prereq\b[\s:=-]+(.+?)\s*$/; $1 || undef }
         grep { /dest\.prereq/ } <$content>
     ) {
-        my @files = <"$_/$type*">;
+        my $rel_dir = _rel2dir($_);
+        my @files   = <"$rel_dir/$type*">;
+
         die "Unable to find prereq \"$_/$type*\"\n" unless ( $files[0] );
-        $self->_execute( $files[0], $run_quiet, 'dependency' ) or return 0 if (
-            ( $type eq 'deploy' and not -f '.dest/' . $files[0] ) or
-            ( $type eq 'revert' and -f '.dest/' . $files[0] )
+        my $dest_file = _rel2dir( '.dest/' . _rel2root( $files[0] ) );
+
+        $self->_execute(
+            ( ( $type ne 'revert' ) ? $files[0] : $dest_file ),
+            $run_quiet,
+            'dependency',
+        ) or return 0 if (
+            ( $type eq 'deploy' and not -f $dest_file ) or
+            ( $type eq 'revert' and     -f $dest_file )
         );
     }
 
     my $wrap;
     shift @nodes if ( $nodes[0] eq '.dest' );
     while (@nodes) {
-        my $path = join( '/', @nodes );
-        if ( -f "$path/dest.wrap" ) {
-            $wrap = "$path/dest.wrap";
+        my $path = _rel2dir( join( '/', @nodes ) . '/dest.wrap' );
+        if ( -f $path ) {
+            $wrap = $path;
             last;
         }
         pop @nodes;
     }
 
-    my ( $out, $err );
+    my ( $out, $err, $died );
     my $run = sub {
-        eval {
+        try {
+            unless ( ($wrap) ? -x $wrap : -x $file ) {
+                $died = 1;
+                die 'Execute permission denied' . ( ($wrap) ? ' on dest.wrap file' : '' ) . "\n";
+            }
+
             run(
                 [ grep { defined } ( ($wrap) ? $wrap : undef ), $file ],
                 \undef, \$out, \$err,
-            );
+            ) or $died = 1;
+        }
+        catch {
+            $err = $_;
         };
-        if ( $@ or $err ) {
-            ( my $err_str = $@ || $err ) =~ s/\s*at\s+.*$//;
+
+        if ($err) {
+            ( my $err_str = $err ) =~ s/\s*at\s+.*$//;
             chomp($err_str);
-            die "Failed to execute $file: $err_str\n";
+            if ($died) {
+                die "Failed to execute $file: $err_str\n";
+            }
+            else {
+                warn "Warnings from executed $file: $err_str\n";
+            }
         }
     };
 
@@ -433,7 +553,7 @@ sub _execute {
         print "begin - $type: $action\n";
         $run->();
 
-        $file =~ s|^\.dest/||;
+        $file =~ s|(?<!\w)\.dest/||;
         print "ok - $type: $action\n";
 
         if ( $type eq 'deploy' ) {
@@ -445,6 +565,24 @@ sub _execute {
     return 1;
 }
 
+sub _rel2root {
+    my ($dir) = @_;
+    my $path  = path( $dir || '.' );
+
+    try {
+        $path = $path->realpath;
+    }
+    catch {
+        $path = $path->absolute;
+    };
+
+    return $path->relative( $env->{root_dir} )->stringify;
+}
+
+sub _rel2dir {
+    return ( '../' x ( $env->{dir_depth} || 0 ) ) . ( $_[0] || '.' );
+}
+
 1;
 
 __END__
@@ -459,7 +597,7 @@ App::Dest - Deployment State Manager
 
 =head1 VERSION
 
-version 1.14
+version 1.15
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/dest.svg)](https://travis-ci.org/gryphonshafer/dest)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/dest/badge.png)](https://coveralls.io/r/gryphonshafer/dest)
@@ -471,9 +609,14 @@ dest COMMAND [DIR || NAME]
     dest init            # initialize dest for a project
     dest add DIR         # add a directory to dest tracking list
     dest rm DIR          # remove a directory from dest tracking list
-    dest make NAME [EXT] # create a named template set (set of 3 files)
+
     dest watches         # returns a list of watched directories
+    dest putwatch FILE   # set watch list to be what's in a file
+    dest writewatch      # creates watch file in project root directory
+
+    dest make NAME [EXT] # create a named template set (set of 3 files)
     dest list [NAME]     # dump a list of the template set (set of 3 files)
+
     dest status          # check status of tracked directories
     dest diff [NAME]     # display a diff of any modified actions
     dest clean           # reset dest state to match current files/directories
@@ -503,16 +646,16 @@ particular software project using your favorite revision control system.
 Let's also say that you have a database that undergoes schema changes as
 features are developed, and you have various system activities like the
 installation of libraries or other applications. Then let's also say the team
-braches, works on stuff, shares those branches, reverts, merges, etc. And also
+branches, works on stuff, shares those branches, reverts, merges, etc. And also
 from time to time you want to go back in time a bit so you can reproduce a bug.
 Maintaining the database state and the state of the system across all that
 activity can be problematic. dest tries to solve this in a very simple way,
 letting you be able to deploy, revert, and verify to any point in time in
 the development history.
 
-Using dest for production deployment, provisioning, or configuration management
-is not advised. Use something like Angular et al instead. Angular (or whatever
-CM tool you prefer) can use dest to perform some actions.
+Note that using dest for production deployment, provisioning, or configuration
+management is not advised. Use a full-featured configuration management tool
+instead.
 
 =for test_synopsis BEGIN { die "SKIP: skip synopsis check because it's non-Perl\n"; }
 
@@ -529,8 +672,8 @@ while in the root directory of your project. (If you are in a different
 directory, dest will assume that is your project's root directory.)
 
 The initialization will result in a C<.dest> directory being created.
-You'll almost certainly want to add ".dest" to your .gitignore file or
-whatever.
+You'll almost certainly want to add ".dest" to your `.gitignore` file or
+similar revision control ignore file.
 
 =head2 add DIR
 
@@ -552,6 +695,24 @@ the verify file let's you verify the deploy file worked.
 
 This removes a directory from the dest tracking list.
 
+=head2 watches
+
+Returns a list of tracked or watched directories.
+
+=head2 putwatch FILE
+
+Sets the current list of tracked or watched directories to be what's in a file.
+For example, you could do this:
+
+    dest watches > dest.watch
+    echo 'new_dir_to_watch' >> dest.watch
+    dest putwatch dest.watch
+
+=head2 writewatch
+
+Creates (or overwrites) a watch file in the project root directory with the
+contents of the currently watched directories.
+
 =head2 make NAME [EXT]
 
 This is a helper command. Given a directory you've already added, it will create
@@ -573,10 +734,6 @@ Optionally, you can specify an extention for the created files. For example:
     #    db/schema/revert.sql
     #    db/schema/verify.sql
 
-=head2 watches
-
-Returns a list of tracked or watched directories.
-
 =head2 list [NAME]
 
 If provided a name of an action, it does the last step of C<make>. It lists
@@ -824,13 +981,15 @@ L<CPAN Testers|http://www.cpantesters.org/distro/A/App-Dest.html>
 
 =back
 
+=for Pod::Coverage clear watch_list
+
 =head1 AUTHOR
 
 Gryphon Shafer <gryphon@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Gryphon Shafer.
+This software is copyright (c) 2017 by Gryphon Shafer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
